<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ne">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN चालू गर्नुहोस्</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock चालू गर्नुहोस्</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>संख्यालेख्य प्लेट चालू गर्नुहोस्</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>संख्यालेख्य प्लेट अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>टचपेड चालू गर्नुहोस्</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>टचपेड अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>टचपेड चालू वा अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn चालू वा अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>विमान राज्य व्यवस्थापन चालू गर्नुहोस्</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>विमान राज्य व्यवस्थापन अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>व्यवस्थित शक्ति</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>शक्ति सेवाकरी</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>उच्च प्रदर्शनीय</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>विंडो प्रभाव सकारात्मक गर्नुहोस्</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>विंडो प्रभाव अकार्य गर्नुहोस्</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>विंडो प्रभाव सकारात्मक गर्न मित्र छ</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>